Class: Google::Cloud::Bigquery::DataTransfer::V1::DeleteTransferConfigRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/google/cloud/bigquery/data_transfer/v1/doc/google/cloud/bigquery/data_transfer/v1/data_transfer.rb

Overview

A request to delete data transfer information. All associated transfer runs and log messages will be deleted as well.

Instance Attribute Summary collapse

Instance Attribute Details

#name ⇒ String

Returns The field will contain name of the resource requested, for example: projects/\\{project_id}/transferConfigs/\\{config_id}.

Returns:

  • (String) —

    The field will contain name of the resource requested, for example: projects/\\{project_id}/transferConfigs/\\{config_id}



331
# File 'lib/google/cloud/bigquery/data_transfer/v1/doc/google/cloud/bigquery/data_transfer/v1/data_transfer.rb', line 331

class DeleteTransferConfigRequest; end