Class: Google::Cloud::Bigquery::DataTransfer::V1::GetDataSourceRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/google/cloud/bigquery/data_transfer/v1/doc/google/cloud/bigquery/data_transfer/v1/data_transfer.rb

Overview

A request to get data source info.

Instance Attribute Summary collapse

Instance Attribute Details

#name ⇒ String

Returns The field will contain name of the resource requested, for example: projects/\\{project_id}/dataSources/\\{data_source_id}.

Returns:

  • (String) —

    The field will contain name of the resource requested, for example: projects/\\{project_id}/dataSources/\\{data_source_id}



224
# File 'lib/google/cloud/bigquery/data_transfer/v1/doc/google/cloud/bigquery/data_transfer/v1/data_transfer.rb', line 224

class GetDataSourceRequest; end