Class: Google::Cloud::Bigquery::DataTransfer::V1::GetTransferConfigRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/google/cloud/bigquery/data_transfer/v1/doc/google/cloud/bigquery/data_transfer/v1/data_transfer.rb

Overview

A request to get data transfer information.

Instance Attribute Summary collapse

Instance Attribute Details

#name ⇒ String

Returns The field will contain name of the resource requested, for example: projects/\\{project_id}/transferConfigs/\\{config_id}.

Returns:

  • (String) —

    The field will contain name of the resource requested, for example: projects/\\{project_id}/transferConfigs/\\{config_id}



323
# File 'lib/google/cloud/bigquery/data_transfer/v1/doc/google/cloud/bigquery/data_transfer/v1/data_transfer.rb', line 323

class GetTransferConfigRequest; end