Class: Google::Cloud::Bigquery::DataTransfer::V1::ListDataSourcesRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/google/cloud/bigquery/data_transfer/v1/doc/google/cloud/bigquery/data_transfer/v1/data_transfer.rb

Overview

Request to list supported data sources and their data transfer settings.

Instance Attribute Summary collapse

Instance Attribute Details

#page_size ⇒ Integer

Returns Page size. The default page size is the maximum value of 1000 results.

Returns:

  • (Integer) —

    Page size. The default page size is the maximum value of 1000 results.



241
# File 'lib/google/cloud/bigquery/data_transfer/v1/doc/google/cloud/bigquery/data_transfer/v1/data_transfer.rb', line 241

class ListDataSourcesRequest; end

#page_token ⇒ String

Returns Pagination token, which can be used to request a specific page of ListDataSourcesRequest list results. For multiple-page results, ListDataSourcesResponse outputs a next_page token, which can be used as the page_token value to request the next page of list results.

Returns:

  • (String) —

    Pagination token, which can be used to request a specific page of ListDataSourcesRequest list results. For multiple-page results, ListDataSourcesResponse outputs a next_page token, which can be used as the page_token value to request the next page of list results.



241
# File 'lib/google/cloud/bigquery/data_transfer/v1/doc/google/cloud/bigquery/data_transfer/v1/data_transfer.rb', line 241

class ListDataSourcesRequest; end

#parent ⇒ String

Returns The BigQuery project id for which data sources should be returned. Must be in the form: projects/\\{project_id}.

Returns:

  • (String) —

    The BigQuery project id for which data sources should be returned. Must be in the form: projects/\\{project_id}



241
# File 'lib/google/cloud/bigquery/data_transfer/v1/doc/google/cloud/bigquery/data_transfer/v1/data_transfer.rb', line 241

class ListDataSourcesRequest; end