Class: Google::Cloud::Bigquery::Datatransfer::V1::ListTransferConfigsRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/google/cloud/bigquery/data_transfer/v1/doc/google/cloud/bigquery/datatransfer/v1/datatransfer.rb

Overview

A request to list data transfers configured for a BigQuery project.

Instance Attribute Summary collapse

Instance Attribute Details

#data_source_ids ⇒ Array<String>

Returns When specified, only configurations of requested data sources are returned.

Returns:

  • (Array<String>) —

    When specified, only configurations of requested data sources are returned.



352
# File 'lib/google/cloud/bigquery/data_transfer/v1/doc/google/cloud/bigquery/datatransfer/v1/datatransfer.rb', line 352

class ListTransferConfigsRequest; end

#page_size ⇒ Integer

Returns Page size. The default page size is the maximum value of 1000 results.

Returns:

  • (Integer) —

    Page size. The default page size is the maximum value of 1000 results.



352
# File 'lib/google/cloud/bigquery/data_transfer/v1/doc/google/cloud/bigquery/datatransfer/v1/datatransfer.rb', line 352

class ListTransferConfigsRequest; end

#page_token ⇒ String

Returns Pagination token, which can be used to request a specific page of ListTransfersRequest list results. For multiple-page results, ListTransfersResponse outputs a next_page token, which can be used as the page_token value to request the next page of list results.

Returns:

  • (String) —

    Pagination token, which can be used to request a specific page of ListTransfersRequest list results. For multiple-page results, ListTransfersResponse outputs a next_page token, which can be used as the page_token value to request the next page of list results.



352
# File 'lib/google/cloud/bigquery/data_transfer/v1/doc/google/cloud/bigquery/datatransfer/v1/datatransfer.rb', line 352

class ListTransferConfigsRequest; end

#parent ⇒ String

Returns The BigQuery project id for which data sources should be returned: projects/{project_id}.

Returns:

  • (String) —

    The BigQuery project id for which data sources should be returned: projects/{project_id}.



352
# File 'lib/google/cloud/bigquery/data_transfer/v1/doc/google/cloud/bigquery/datatransfer/v1/datatransfer.rb', line 352

class ListTransferConfigsRequest; end