Class: Google::Cloud::Bigquery::Datatransfer::V1::ListTransferLogsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Bigquery::Datatransfer::V1::ListTransferLogsRequest
- Defined in:
- lib/google/cloud/bigquery/data_transfer/v1/doc/google/cloud/bigquery/datatransfer/v1/datatransfer.rb
Overview
A request to get user facing log messages associated with data transfer run.
Instance Attribute Summary collapse
-
#message_types ⇒ Array<Google::Cloud::Bigquery::Datatransfer::V1::TransferMessage::MessageSeverity>
Message types to return.
-
#page_size ⇒ Integer
Page size.
-
#page_token ⇒ String
Pagination token, which can be used to request a specific page of
ListTransferLogsRequestlist results. -
#parent ⇒ String
Transfer run name in the form:
projects/{project_id}/transferConfigs/{config_Id}/runs/{run_id}.
Instance Attribute Details
#message_types ⇒ Array<Google::Cloud::Bigquery::Datatransfer::V1::TransferMessage::MessageSeverity>
Returns Message types to return. If not populated - INFO, WARNING and ERROR messages are returned.
432 |
# File 'lib/google/cloud/bigquery/data_transfer/v1/doc/google/cloud/bigquery/datatransfer/v1/datatransfer.rb', line 432 class ListTransferLogsRequest; end |
#page_size ⇒ Integer
Returns Page size. The default page size is the maximum value of 1000 results.
432 |
# File 'lib/google/cloud/bigquery/data_transfer/v1/doc/google/cloud/bigquery/datatransfer/v1/datatransfer.rb', line 432 class ListTransferLogsRequest; end |
#page_token ⇒ String
Returns Pagination token, which can be used to request a specific page
of ListTransferLogsRequest list results. For multiple-page
results, ListTransferLogsResponse outputs
a next_page token, which can be used as the
page_token value to request the next page of list results.
432 |
# File 'lib/google/cloud/bigquery/data_transfer/v1/doc/google/cloud/bigquery/datatransfer/v1/datatransfer.rb', line 432 class ListTransferLogsRequest; end |
#parent ⇒ String
Returns Transfer run name in the form:
projects/{project_id}/transferConfigs/{config_Id}/runs/{run_id}.
432 |
# File 'lib/google/cloud/bigquery/data_transfer/v1/doc/google/cloud/bigquery/datatransfer/v1/datatransfer.rb', line 432 class ListTransferLogsRequest; end |